@@ -7,6 +7,8 @@ from colorama import Fore, Style
 
 from nlab_inf_engine_scripts.InfEngineServer import InfEngineServer
 
+VERSION = "0.0.17"
+
 
 def main():
     def success():
@@ -112,7 +114,7 @@ def main():
             print(f"InfServer status: {status}\n")
         elif args.version:
 
-            print(f"0.0.16")
+            print(VERSION)
         elif args.engine_version:
 
             print(f"{server.version()}")
