@@ -314,7 +314,9 @@ class InfEngineServer:
                 self._logger.error(
                     f"Can't start InfEngine server: {res}, {completed_process.returncode}"
                 )
-                raise Exception(f"Can't start InfEngine server: {res}, {completed_process.returncode}")
+                raise Exception(
+                    f"Can't start InfEngine server: {res}, {completed_process.returncode}"
+                )
 
         # Sleep until the server is started
         while True:
